@@ -1,11 +1,24 @@
 #pragma once
 
 #include "../DesktopTypes.hpp"
-#include "../../SharedDefs.hpp"
+#include "../../helpers/signal/Signal.hpp"
 
 class CWLSurfaceResource;
 
 namespace Desktop {
+    enum eFocusReason : uint8_t {
+        FOCUS_REASON_UNKNOWN = 0,
+        FOCUS_REASON_FFM,
+        FOCUS_REASON_KEYBIND,
+        FOCUS_REASON_CLICK,
+        FOCUS_REASON_OTHER,
+        FOCUS_REASON_DESKTOP_STATE_CHANGE,
+        FOCUS_REASON_NEW_WINDOW,
+        FOCUS_REASON_GHOSTS,
+    };
+
+    bool isHardInputFocusReason(eFocusReason r);
+
     class CFocusState {
       public:
         CFocusState();
@@ -15,8 +28,8 @@ namespace Desktop {
         CFocusState(CFocusState&)       = delete;
         CFocusState(const CFocusState&) = delete;
 
-        void                   fullWindowFocus(PHLWINDOW w, SP<CWLSurfaceResource> surface = nullptr, bool forceFSCycle = false);
-        void                   rawWindowFocus(PHLWINDOW w, SP<CWLSurfaceResource> surface = nullptr);
+        void                   fullWindowFocus(PHLWINDOW w, eFocusReason reason, SP<CWLSurfaceResource> surface = nullptr, bool forceFSCycle = false);
+        void                   rawWindowFocus(PHLWINDOW w, eFocusReason reason, SP<CWLSurfaceResource> surface = nullptr);
         void                   rawSurfaceFocus(SP<CWLSurfaceResource> s, PHLWINDOW pWindowOwner = nullptr);
         void                   rawMonitorFocus(PHLMONITOR m);
 
@@ -31,7 +44,7 @@ namespace Desktop {
         PHLWINDOWREF           m_focusWindow;
         PHLMONITORREF          m_focusMonitor;
 
-        SP<HOOK_CALLBACK_FN>   m_windowOpen, m_windowClose;
+        CHyprSignalListener    m_windowOpen, m_windowClose;
     };
 
     SP<CFocusState> focusState();
