@@ -26,8 +26,19 @@ struct SWorkspaceRule;
 
 class IWindowTransformer;
 
+namespace Layout {
+    class ITarget;
+    class CWindowTarget;
+}
+
+namespace Desktop {
+    enum eFocusReason : uint8_t;
+}
+
 namespace Desktop::View {
 
+    class CGroup;
+
     enum eGroupRules : uint8_t {
         // effective only during first map, except for _ALWAYS variant
         GROUP_NONE        = 0,
@@ -38,6 +49,7 @@ namespace Desktop::View {
         GROUP_LOCK_ALWAYS = 1 << 4,
         GROUP_INVADE      = 1 << 5, // Force enter a group, event if lock is engaged
         GROUP_OVERRIDE    = 1 << 6, // Override other rules
+        GROUP_DENY        = 1 << 7, // deny
     };
 
     enum eGetWindowProperties : uint8_t {
@@ -61,6 +73,11 @@ namespace Desktop::View {
         SUPPRESS_FULLSCREEN_OUTPUT  = 1 << 4,
     };
 
+    struct SWindowActiveEvent {
+        PHLWINDOW    window = nullptr;
+        eFocusReason reason = sc<eFocusReason>(0) /* unknown */;
+    };
+
     struct SInitialWorkspaceToken {
         PHLWINDOWREF primaryOwner;
         std::string  workspace;
@@ -92,11 +109,17 @@ namespace Desktop::View {
 
         struct {
             CSignalT<> destroy;
+            CSignalT<> unmap;
+            CSignalT<> hide;
+            CSignalT<> resize;
+            CSignalT<> monitorChanged;
         } m_events;
 
         WP<CXDGSurfaceResource> m_xdgSurface;
         WP<CXWaylandSurface>    m_xwaylandSurface;
 
+        SP<Layout::ITarget>     m_target;
+
         // this is the position and size of the "bounding box"
         Vector2D m_position = Vector2D(0, 0);
         Vector2D m_size     = Vector2D(0, 0);
@@ -112,30 +135,21 @@ namespace Desktop::View {
         std::optional<std::pair<uint32_t, Vector2D>> m_pendingSizeAck;
         std::vector<std::pair<uint32_t, Vector2D>>   m_pendingSizeAcks;
 
-        // for restoring floating statuses
-        Vector2D m_lastFloatingSize;
-        Vector2D m_lastFloatingPosition;
-
         // for floating window offset in workspace animations
         Vector2D m_floatingOffset = Vector2D(0, 0);
 
-        // this is used for pseudotiling
-        bool     m_isPseudotiled = false;
-        Vector2D m_pseudoSize    = Vector2D(1280, 720);
-
         // for recovering relative cursor position
         Vector2D         m_relativeCursorCoordsOnLastWarp = Vector2D(-1, -1);
 
         bool             m_firstMap        = false; // for layouts
         bool             m_isFloating      = false;
-        bool             m_draggingTiled   = false; // for dragging around tiled windows
         SFullscreenState m_fullscreenState = {.internal = FSMODE_NONE, .client = FSMODE_NONE};
         std::string      m_title           = "";
         std::string      m_class           = "";
         std::string      m_initialTitle    = "";
         std::string      m_initialClass    = "";
         PHLWORKSPACE     m_workspace;
-        PHLMONITORREF    m_monitor;
+        PHLMONITORREF    m_monitor, m_prevMonitor;
 
         bool             m_isMapped = false;
 
@@ -229,15 +243,13 @@ namespace Desktop::View {
         std::string m_initialWorkspaceToken = "";
 
         // for groups
-        struct SGroupData {
-            PHLWINDOWREF pNextWindow; // nullptr means no grouping. Self means single group.
-            bool         head   = false;
-            bool         locked = false; // per group lock
-            bool         deny   = false; // deny window from enter a group or made a group
-        } m_groupData;
-        uint16_t m_groupRules = Desktop::View::GROUP_NONE;
+        SP<CGroup> m_group;
+        uint16_t   m_groupRules = Desktop::View::GROUP_NONE;
 
-        bool     m_tearingHint = false;
+        bool       m_tearingHint = false;
+
+        // Stable ID for ext_foreign_toplevel_list
+        const uint64_t m_stableID = 0x2137;
 
         // ANR
         PHLANIMVAR<float> m_notRespondingTint;
@@ -300,21 +312,6 @@ namespace Desktop::View {
         bool                       isInCurvedCorner(double x, double y);
         bool                       hasPopupAt(const Vector2D& pos);
         int                        popupsCount();
-        void                       applyGroupRules();
-        void                       createGroup();
-        void                       destroyGroup();
-        PHLWINDOW                  getGroupHead();
-        PHLWINDOW                  getGroupTail();
-        PHLWINDOW                  getGroupCurrent();
-        PHLWINDOW                  getGroupPrevious();
-        PHLWINDOW                  getGroupWindowByIndex(int);
-        bool                       hasInGroup(PHLWINDOW);
-        int                        getGroupSize();
-        bool                       canBeGroupedInto(PHLWINDOW pWindow);
-        void                       setGroupCurrent(PHLWINDOW pWindow);
-        void                       insertWindowToGroup(PHLWINDOW pWindow);
-        void                       updateGroupOutputs();
-        void                       switchWithWindowInGroup(PHLWINDOW pWindow);
         void                       setAnimationsToMove();
         void                       onWorkspaceAnimUpdate();
         void                       onFocusAnimUpdate();
@@ -328,8 +325,6 @@ namespace Desktop::View {
         PHLWINDOW                  getSwallower();
         bool                       isX11OverrideRedirect();
         bool                       isModal();
-        Vector2D                   requestedMinSize();
-        Vector2D                   requestedMaxSize();
         Vector2D                   realToReportSize();
         Vector2D                   realToReportPosition();
         Vector2D                   xwaylandSizeToReal(Vector2D size);
@@ -349,6 +344,8 @@ namespace Desktop::View {
         std::optional<Vector2D>    calculateExpression(const std::string& s);
         std::optional<Vector2D>    minSize();
         std::optional<Vector2D>    maxSize();
+        SP<Layout::ITarget>        layoutTarget();
+        bool                       canBeGroupedInto(SP<CGroup> group);
 
         CBox                       getWindowMainSurfaceBox() const {
             return {m_realPosition->value().x, m_realPosition->value().y, m_realSize->value().x, m_realSize->value().y};
