@@ -20,16 +20,16 @@ class CHyprError {
 
   private:
     void              createQueued();
-    std::string       m_szQueued = "";
-    CHyprColor        m_cQueued;
-    bool              m_bQueuedDestroy = false;
-    bool              m_bIsCreated     = false;
-    SP<CTexture>      m_pTexture;
-    PHLANIMVAR<float> m_fFadeOpacity;
-    CBox              m_bDamageBox  = {0, 0, 0, 0};
-    float             m_fLastHeight = 0.F;
+    std::string       m_queued = "";
+    CHyprColor        m_queuedColor;
+    bool              m_queuedDestroy = false;
+    bool              m_isCreated     = false;
+    SP<CTexture>      m_texture;
+    PHLANIMVAR<float> m_fadeOpacity;
+    CBox              m_damageBox  = {0, 0, 0, 0};
+    float             m_lastHeight = 0.F;
 
-    bool              m_bMonitorChanged = false;
+    bool              m_monitorChanged = false;
 };
 
 inline UP<CHyprError> g_pHyprError; // This is a full-screen error. Treat it with respect, and there can only be one at a time.
