@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "dd220efe7b1e292415bd0ea7161f63df9c95bfd3"
-#define GIT_BRANCH         "v0.53.3"
-#define GIT_COMMIT_MESSAGE "version: bump to 0.53.3"
-#define GIT_COMMIT_DATE    "Sat Jan 24 20:02:06 2026"
+#define GIT_COMMIT_HASH    "0002f148c9a4fe421a9d33c0faa5528cdc411e62"
+#define GIT_BRANCH         "v0.54.0"
+#define GIT_COMMIT_MESSAGE "version: bump to 0.54.0"
+#define GIT_COMMIT_DATE    "Fri Feb 27 18:03:19 2026"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.53.3"
-#define GIT_COMMITS        "6793"
+#define GIT_TAG            "v0.54.0"
+#define GIT_COMMITS        "6935"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
