@@ -11,6 +11,7 @@ class CXWaylandSurfaceResource;
 #ifdef NO_XWAYLAND
 using xcb_pixmap_t         = uint32_t;
 using xcb_window_t         = uint32_t;
+using xcb_atom_t           = uint32_t;
 using xcb_icccm_wm_hints_t = struct {
     int32_t      flags;
     uint32_t     input;
@@ -111,6 +112,7 @@ class CXWaylandSurface {
     void unmap();
     void considerMap();
     void setWithdrawn(bool withdrawn);
+    void recheckSupportedProps();
 
     struct {
         CHyprSignalListener destroyResource;
@@ -118,5 +120,7 @@ class CXWaylandSurface {
         CHyprSignalListener commitSurface;
     } m_listeners;
 
+    std::unordered_map<xcb_atom_t, bool> m_supportedProps;
+
     friend class CXWM;
 };
